| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Transcribe.ListTagsForResource
Description
Lists all tags associated with the specified transcription job, vocabulary, model, or resource.
To learn more about using tags with Amazon Transcribe, refer to Tagging resources.
Synopsis
- data ListTagsForResource = ListTagsForResource' {
- resourceArn :: Text
- newListTagsForResource :: Text -> ListTagsForResource
- listTagsForResource_resourceArn :: Lens' ListTagsForResource Text
- data ListTagsForResourceResponse = ListTagsForResourceResponse' {
- resourceArn :: Maybe Text
- tags :: Maybe (NonEmpty Tag)
- httpStatus :: Int
- newListTagsForResourceResponse :: Int -> ListTagsForResourceResponse
- listTagsForResourceResponse_resourceArn :: Lens' ListTagsForResourceResponse (Maybe Text)
- listTagsForResourceResponse_tags :: Lens' ListTagsForResourceResponse (Maybe (NonEmpty Tag))
- listTagsForResourceResponse_httpStatus :: Lens' ListTagsForResourceResponse Int
Creating a Request
data ListTagsForResource Source #
See: newListTagsForResource smart constructor.
Constructors
| ListTagsForResource' | |
Fields
| |
Instances
newListTagsForResource Source #
Arguments
| :: Text | |
| -> ListTagsForResource |
Create a value of ListTagsForResource with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
ListTagsForResource, listTagsForResource_resourceArn - Returns a list of all tags associated with the specified Amazon Resource
Name (ARN). ARNs have the format
arn:partition:service:region:account-id:resource-type/resource-id.
For example,
arn:aws:transcribe:us-west-2:111122223333:transcription-job/transcription-job-name.
Valid values for resource-type are: transcription-job,
medical-transcription-job, vocabulary, medical-vocabulary,
vocabulary-filter, and language-model.
Request Lenses
listTagsForResource_resourceArn :: Lens' ListTagsForResource Text Source #
Returns a list of all tags associated with the specified Amazon Resource
Name (ARN). ARNs have the format
arn:partition:service:region:account-id:resource-type/resource-id.
For example,
arn:aws:transcribe:us-west-2:111122223333:transcription-job/transcription-job-name.
Valid values for resource-type are: transcription-job,
medical-transcription-job, vocabulary, medical-vocabulary,
vocabulary-filter, and language-model.
Destructuring the Response
data ListTagsForResourceResponse Source #
See: newListTagsForResourceResponse smart constructor.
Constructors
| ListTagsForResourceResponse' | |
Fields
| |
Instances
newListTagsForResourceResponse Source #
Create a value of ListTagsForResourceResponse with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
ListTagsForResource, listTagsForResourceResponse_resourceArn - The Amazon Resource Name (ARN) specified in your request.
ListTagsForResourceResponse, listTagsForResourceResponse_tags - Lists all tags associated with the given transcription job, vocabulary,
model, or resource.
$sel:httpStatus:ListTagsForResourceResponse', listTagsForResourceResponse_httpStatus - The response's http status code.
Response Lenses
listTagsForResourceResponse_resourceArn :: Lens' ListTagsForResourceResponse (Maybe Text) Source #
The Amazon Resource Name (ARN) specified in your request.
listTagsForResourceResponse_tags :: Lens' ListTagsForResourceResponse (Maybe (NonEmpty Tag)) Source #
Lists all tags associated with the given transcription job, vocabulary, model, or resource.
listTagsForResourceResponse_httpStatus :: Lens' ListTagsForResourceResponse Int Source #
The response's http status code.