| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Transcribe.Types.NonTalkTimeFilter
Description
Synopsis
- data NonTalkTimeFilter = NonTalkTimeFilter' {}
- newNonTalkTimeFilter :: NonTalkTimeFilter
- nonTalkTimeFilter_absoluteTimeRange :: Lens' NonTalkTimeFilter (Maybe AbsoluteTimeRange)
- nonTalkTimeFilter_negate :: Lens' NonTalkTimeFilter (Maybe Bool)
- nonTalkTimeFilter_relativeTimeRange :: Lens' NonTalkTimeFilter (Maybe RelativeTimeRange)
- nonTalkTimeFilter_threshold :: Lens' NonTalkTimeFilter (Maybe Natural)
Documentation
data NonTalkTimeFilter Source #
Flag the presence or absence of periods of silence in your Call Analytics transcription output.
Rules using NonTalkTimeFilter are designed to match:
- The presence of silence at specified periods throughout the call
- The presence of speech at specified periods throughout the call
See Rule criteria for batch categories for usage examples.
See: newNonTalkTimeFilter smart constructor.
Constructors
| NonTalkTimeFilter' | |
Fields
| |
Instances
newNonTalkTimeFilter :: NonTalkTimeFilter Source #
Create a value of NonTalkTimeFilter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:absoluteTimeRange:NonTalkTimeFilter', nonTalkTimeFilter_absoluteTimeRange - Makes it possible to specify a time range (in milliseconds) in your
audio, during which you want to search for a period of silence. See for
more detail.
$sel:negate:NonTalkTimeFilter', nonTalkTimeFilter_negate - Set to TRUE to flag periods of speech. Set to FALSE to flag periods
of silence
$sel:relativeTimeRange:NonTalkTimeFilter', nonTalkTimeFilter_relativeTimeRange - Makes it possible to specify a time range (in percentage) in your media
file, during which you want to search for a period of silence. See for
more detail.
$sel:threshold:NonTalkTimeFilter', nonTalkTimeFilter_threshold - Specify the duration, in milliseconds, of the period of silence that you
want to flag. For example, you can flag a silent period that lasts
30,000 milliseconds.
nonTalkTimeFilter_absoluteTimeRange :: Lens' NonTalkTimeFilter (Maybe AbsoluteTimeRange) Source #
Makes it possible to specify a time range (in milliseconds) in your audio, during which you want to search for a period of silence. See for more detail.
nonTalkTimeFilter_negate :: Lens' NonTalkTimeFilter (Maybe Bool) Source #
Set to TRUE to flag periods of speech. Set to FALSE to flag periods
of silence
nonTalkTimeFilter_relativeTimeRange :: Lens' NonTalkTimeFilter (Maybe RelativeTimeRange) Source #
Makes it possible to specify a time range (in percentage) in your media file, during which you want to search for a period of silence. See for more detail.
nonTalkTimeFilter_threshold :: Lens' NonTalkTimeFilter (Maybe Natural) Source #
Specify the duration, in milliseconds, of the period of silence that you want to flag. For example, you can flag a silent period that lasts 30,000 milliseconds.