| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Transcribe.Types.SentimentFilter
Description
Synopsis
- data SentimentFilter = SentimentFilter' {}
- newSentimentFilter :: NonEmpty SentimentValue -> SentimentFilter
- sentimentFilter_absoluteTimeRange :: Lens' SentimentFilter (Maybe AbsoluteTimeRange)
- sentimentFilter_negate :: Lens' SentimentFilter (Maybe Bool)
- sentimentFilter_participantRole :: Lens' SentimentFilter (Maybe ParticipantRole)
- sentimentFilter_relativeTimeRange :: Lens' SentimentFilter (Maybe RelativeTimeRange)
- sentimentFilter_sentiments :: Lens' SentimentFilter (NonEmpty SentimentValue)
Documentation
data SentimentFilter Source #
Flag the presence or absence of specific sentiments detected in your Call Analytics transcription output.
Rules using SentimentFilter are designed to match:
- The presence or absence of a positive sentiment felt by the customer, agent, or both at specified points in the call
- The presence or absence of a negative sentiment felt by the customer, agent, or both at specified points in the call
- The presence or absence of a neutral sentiment felt by the customer, agent, or both at specified points in the call
- The presence or absence of a mixed sentiment felt by the customer, the agent, or both at specified points in the call
See Rule criteria for batch categories for usage examples.
See: newSentimentFilter smart constructor.
Constructors
| SentimentFilter' | |
Fields
| |
Instances
Create a value of SentimentFilter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:absoluteTimeRange:SentimentFilter', sentimentFilter_absoluteTimeRange - Makes it possible to specify a time range (in milliseconds) in your
audio, during which you want to search for the specified sentiments. See
for more detail.
$sel:negate:SentimentFilter', sentimentFilter_negate - Set to TRUE to flag the sentiments that you didn't include in your
request. Set to FALSE to flag the sentiments that you specified in
your request.
$sel:participantRole:SentimentFilter', sentimentFilter_participantRole - Specify the participant that you want to flag. Omitting this parameter
is equivalent to specifying both participants.
$sel:relativeTimeRange:SentimentFilter', sentimentFilter_relativeTimeRange - Makes it possible to specify a time range (in percentage) in your media
file, during which you want to search for the specified sentiments. See
for more detail.
$sel:sentiments:SentimentFilter', sentimentFilter_sentiments - Specify the sentiments that you want to flag.
sentimentFilter_absoluteTimeRange :: Lens' SentimentFilter (Maybe AbsoluteTimeRange) Source #
Makes it possible to specify a time range (in milliseconds) in your audio, during which you want to search for the specified sentiments. See for more detail.
sentimentFilter_negate :: Lens' SentimentFilter (Maybe Bool) Source #
Set to TRUE to flag the sentiments that you didn't include in your
request. Set to FALSE to flag the sentiments that you specified in
your request.
sentimentFilter_participantRole :: Lens' SentimentFilter (Maybe ParticipantRole) Source #
Specify the participant that you want to flag. Omitting this parameter is equivalent to specifying both participants.
sentimentFilter_relativeTimeRange :: Lens' SentimentFilter (Maybe RelativeTimeRange) Source #
Makes it possible to specify a time range (in percentage) in your media file, during which you want to search for the specified sentiments. See for more detail.
sentimentFilter_sentiments :: Lens' SentimentFilter (NonEmpty SentimentValue) Source #
Specify the sentiments that you want to flag.