| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Transcribe.Types.Tag
Description
Documentation
Adds metadata, in the form of a key:value pair, to the specified resource.
For example, you could add the tag Department:Sales to a resource to
indicate that it pertains to your organization's sales department. You
can also use tags for tag-based access control.
To learn more about tagging, see Tagging resources.
See: newTag smart constructor.
Constructors
| Tag' | |
Fields
| |
Instances
| FromJSON Tag Source # | |
| ToJSON Tag Source # | |
Defined in Amazonka.Transcribe.Types.Tag | |
| Generic Tag Source # | |
| Read Tag Source # | |
| Show Tag Source # | |
| NFData Tag Source # | |
Defined in Amazonka.Transcribe.Types.Tag | |
| Eq Tag Source # | |
| Hashable Tag Source # | |
Defined in Amazonka.Transcribe.Types.Tag | |
| type Rep Tag Source # | |
Defined in Amazonka.Transcribe.Types.Tag type Rep Tag = D1 ('MetaData "Tag" "Amazonka.Transcribe.Types.Tag" "amazonka-transcribe-2.0-4BjJqzwmm0K94bsEMe1tnF" 'False) (C1 ('MetaCons "Tag'" 'PrefixI 'True) (S1 ('MetaSel ('Just "key") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 Text) :*: S1 ('MetaSel ('Just "value") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 Text))) | |
Create a value of Tag with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:key:Tag', tag_key - The first part of a key:value pair that forms a tag associated with a
given resource. For example, in the tag Department:Sales, the key is
'Department'.
$sel:value:Tag', tag_value - The second part of a key:value pair that forms a tag associated with a
given resource. For example, in the tag Department:Sales, the value is
'Sales'.
Note that you can set the value of a tag to an empty string, but you can't set the value of a tag to null. Omitting the tag value is the same as using an empty string.
tag_key :: Lens' Tag Text Source #
The first part of a key:value pair that forms a tag associated with a
given resource. For example, in the tag Department:Sales, the key is
'Department'.
tag_value :: Lens' Tag Text Source #
The second part of a key:value pair that forms a tag associated with a
given resource. For example, in the tag Department:Sales, the value is
'Sales'.
Note that you can set the value of a tag to an empty string, but you can't set the value of a tag to null. Omitting the tag value is the same as using an empty string.